Skip to contents

Prints the sound that an animal makes, by creating a wrapper around paste0().

Usage

animal_sounds(animal, sound = NULL)

Arguments

animal

A character vector of length 1

sound

A character vector of length 1

Value

A string that combines the animal name and sound.

Examples

animal_sounds("dog", "woof")
#> [1] "The dog goes woof!"